@@ -1,9 +1,6 @@
 
 from django.db import transaction
 from django.shortcuts import redirect, render
-from django.contrib import messages
-from django.utils.safestring import mark_safe
-from django.template.loader import render_to_string
 
 from cart.lib import get_cart
 
@@ -39,11 +36,6 @@ def checkout(request):
 
         send_new_order_notifications(request, order)
 
-        message = render_to_string(
-            'orders/new_order_message.html', {'order': order})
-
-        messages.success(request, mark_safe(message))
-
         return redirect('home')
 
     return render(request, 'orders/checkout.html', {'form': form})
